@@ -57,8 +57,8 @@ def main():
     # print("Testing style database...")
     # import flatland.tests.styledb_test
 
-    print("Testing tablet draw...")
-    import flatland.tests.tablet_test
+    # print("Testing tablet draw...")
+    # import flatland.tests.tablet_test
     print("No problemo")
 
 
